# MCP JetBrains Proxy

[![PyPI version](https://badge.fury.io/py/mcp-jetbrains-proxy.svg)](https://badge.fury.io/py/mcp-jetbrains-proxy)
[![Python Versions](https://img.shields.io/pypi/pyversions/mcp-jetbrains-proxy.svg)](https://pypi.org/project/mcp-jetbrains-proxy/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![CI/CD](https://github.com/leobuskin/mcp_jetbrains_proxy/actions/workflows/ci.yml/badge.svg)](https://github.com/leobuskin/mcp_jetbrains_proxy/actions/workflows/ci.yml)

A Python implementation of Model Context Protocol (MCP) proxy for JetBrains IDEs. This package provides a bridge between LLM services and JetBrains IDEs using the MCP protocol.

Check out:   
[Original MCP JetBrains Proxy](https://github.com/JetBrains/mcp-jetbrains)  
[MCP JetBrains Server](https://github.com/JetBrains/mcp-server-plugin)  


## Installation

```bash
pip install mcp_jetbrains_proxy
```

## License

MIT
